#ifndef INDII_TINT_GUI_CLUSTERIMAGECHECKBOX_HPP
#define INDII_TINT_GUI_CLUSTERIMAGECHECKBOX_HPP

#include "wx/wx.h"

namespace indii {
  namespace tint {
    class ClusterImage;
    namespace gui {
      class ClusterImageViewer;

/**
 * Check box for turning on and off a cluster in an image.
 *
 * @author Lawrence Murray <lawrence@indii.org>
 * @version $Rev: 13 $
 * @date $Date: 2007-08-11 13:17:58 +0100 (Sat, 11 Aug 2007) $
 */
class ClusterImageCheckBox : public wxCheckBox {
public:
  /**
   * Constructor.
   *
   * @param parent Parent window.
   * @param image Cluster image to edit.
   * @param viewer Viewer associated with the same cluster image.
   * @param cluster Cluster to turn on and off.
   */
  ClusterImageCheckBox(wxWindow* parent, ClusterImage* image,
      ClusterImageViewer* viewer, int cluster);

  /**
   * Destructor.
   */
  virtual ~ClusterImageCheckBox();

  /**
   * Process click event.
   */
  void OnClick(wxCommandEvent& event);

private:
  /**
   * Cluster image to edit.
   */
  ClusterImage* image;

  /**
   * Viewer associated with the same cluster image.
   */
  ClusterImageViewer* viewer;

  /**
   * Cluster to turn on and off.
   */
  int cluster;

  DECLARE_EVENT_TABLE()

};

    }
  }
}

#endif
