#include "ClusterImageEditor.hpp"

#include "Workspace.hpp"
#include "ClusterImageViewer.hpp"
#include "ClusterImageCheckBox.hpp"
#include "Thumbnail.hpp"
#include "../ClusterImage.hpp"

#include "wx/gbsizer.h"

using namespace indii::tint;
using namespace indii::tint::gui;

#define MAX_THUMB_WIDTH 160
#define MAX_THUMB_HEIGHT 120
#define SPACER_SIZE 4

ClusterImageEditor::ClusterImageEditor(Workspace* workspace,
    ClusterImage* image, ClusterImageViewer* viewer) :
    wxScrolledWindow(workspace) {
  this->image = image;
  this->viewer = viewer;
  this->panel = new wxPanel(this);
  
  int i, k, width, height, thumbWidth, thumbHeight;

  wxGridBagSizer* sizer = new wxGridBagSizer(SPACER_SIZE,SPACER_SIZE);

  /* thumbnail width and height */
  width = image->GetWidth();
  height = image->GetHeight();

  if (width > MAX_THUMB_WIDTH) {
    thumbWidth = MAX_THUMB_WIDTH;
    thumbHeight = height * thumbWidth / width;
    width = thumbWidth;
    height = thumbHeight;
  }
  if (height > MAX_THUMB_HEIGHT) {
    thumbHeight = MAX_THUMB_HEIGHT;
    thumbWidth = width * thumbHeight / height;
  }

  /* cluster thumbnails */
  k = image->GetNumClusters();
  for (i = 0; i < k; i++) {
    image->ShowCluster(i, true);
    wxImage* thumb = new wxImage(image->Scale(thumbWidth, thumbHeight,
        wxIMAGE_QUALITY_HIGH));
    Thumbnail* canvas = new Thumbnail(panel, thumb);
    wxCheckBox* checkBox = new ClusterImageCheckBox(panel, image, viewer, i);
    sizer->Add(canvas, wxGBPosition(1,i+1), wxDefaultSpan, wxALIGN_CENTER);
    sizer->Add(checkBox, wxGBPosition(2,i+1), wxDefaultSpan, wxALIGN_CENTER);

    image->ShowCluster(i, false);
  }

  /* flexible columns on either side to centre thumbnails */
  sizer->AddGrowableCol(0,1);
  sizer->Add(new wxPanel(panel), wxGBPosition(0,0), wxGBSpan(3,1), wxEXPAND);
  sizer->AddGrowableCol(k+1,1);
  sizer->Add(new wxPanel(panel), wxGBPosition(0,k+1), wxGBSpan(3,1), wxEXPAND);

  panel->SetSizer(sizer);

  /* add panel to scrolled window */
  wxBoxSizer* scrollSizer = new wxBoxSizer(wxVERTICAL);
  scrollSizer->Add(panel);
  SetSizer(scrollSizer);

  wxScrolledWindow::SetScrollbars(1, 1, 100, 100);
}

ClusterImageEditor::~ClusterImageEditor() {
  //
}

ClusterImage* ClusterImageEditor::GetClusterImage() {
  return image;
}

wxSize ClusterImageEditor::GetBestSize() {
  return panel->GetBestSize();
}

BEGIN_EVENT_TABLE(ClusterImageEditor, wxPanel)
END_EVENT_TABLE()
