#include "ClusterImageViewer.hpp"

#include "../ClusterImage.hpp"
#include "Workspace.hpp"

#define MAX_ZOOM_IN 8
#define MAX_ZOOM_OUT 16

using namespace indii::tint;
using namespace indii::tint::gui;

ClusterImageViewer::ClusterImageViewer(wxWindow* parent,
    ClusterImage* image) : wxScrolledWindow(parent) {
  this->image = image;
  this->scaledImage = image;
  this->zoomNumerator = 1;
  this->zoomDenominator = 1;

  ScaleImage();
  SetScrollbars();
}

ClusterImageViewer::~ClusterImageViewer() {
  if (scaledImage != image) {
    delete scaledImage;
  }
}

void ClusterImageViewer::ZoomIn() {
  if (zoomDenominator == 1) {
    if (zoomNumerator < MAX_ZOOM_IN) {
      zoomNumerator++;
    }
  } else {
    zoomDenominator--;
  }

  ScaleImage();
  SetScrollbars();

  /* post-condition */
  assert(zoomNumerator >= 1 && zoomDenominator >= 1);
}

void ClusterImageViewer::ZoomOut() {
  if (zoomNumerator == 1) {
    if (zoomDenominator < MAX_ZOOM_OUT) {
      zoomDenominator++;
    }
  } else {
    zoomNumerator--;
  }

  ScaleImage();
  SetScrollbars();

  /* post-condition */
  assert(zoomNumerator >= 1 && zoomDenominator >= 1);
}

void ClusterImageViewer::ZoomNormal() {
  zoomNumerator = 1;
  zoomDenominator = 1;

  ScaleImage();
  SetScrollbars();
}

void ClusterImageViewer::Notify() {
  ScaleImage();
  SetScrollbars();
  Refresh();
}

void ClusterImageViewer::OnDraw(wxDC& dc) {
  int width = image->GetWidth() * zoomNumerator / zoomDenominator;
  int height = image->GetHeight() * zoomNumerator / zoomDenominator;
  int windowWidth = GetSize().GetWidth();
  int windowHeight = GetSize().GetHeight();
  int posX = (windowWidth > width) ? (windowWidth - width) / 2 : 0;
  int posY = (windowHeight > height) ? (windowHeight - height) / 2 : 0;

  dc.Clear();

  /* draw decorations */
  dc.SetBrush(*wxTRANSPARENT_BRUSH);
  dc.SetPen(*wxBLACK_PEN);
  dc.DrawRectangle(posX, posY, width+2, height+2);
  dc.DrawLine(posX+width+2, posY+1, posX+width+2, posY+height+2);
  dc.DrawLine(posX+width+3, posY+2, posX+width+3, posY+height+3);
  dc.DrawLine(posX+1, posY+height+2, posX+width+2, posY+height+2);
  dc.DrawLine(posX+2, posY+height+3, posX+width+3, posY+height+3);

  /* draw image */
  dc.DrawBitmap(wxBitmap(*scaledImage), posX+1, posY+1, false);
}

void ClusterImageViewer::OnSize(wxSizeEvent& event) {
  this->Refresh();
}

void ClusterImageViewer::SetScrollbars() {
  int windowWidth = GetSize().GetWidth();
  int windowHeight = GetSize().GetHeight();
  int width = image->GetWidth() * zoomNumerator / zoomDenominator;
  int height = image->GetHeight() * zoomNumerator / zoomDenominator;
  int maxX = (windowWidth > width) ? windowWidth : width;
  int maxY = (windowHeight > height) ? windowHeight : height;
  int xScrollRate = maxX / 100;
  int yScrollRate = maxY / 100;

  wxScrolledWindow::SetScrollbars(xScrollRate, yScrollRate, 100, 100);
}

void ClusterImageViewer::ScaleImage() {
  if (scaledImage != image) {
    delete scaledImage;
  }

  if (zoomNumerator == 1 && zoomDenominator == 1) {
    scaledImage = image;
  } else {
    int width = image->GetWidth() * zoomNumerator / zoomDenominator;
    int height = image->GetHeight() * zoomNumerator / zoomDenominator;

    scaledImage = new wxImage(image->Scale(width, height));
  }
}

BEGIN_EVENT_TABLE(ClusterImageViewer, wxWindow)
EVT_PAINT(ClusterImageViewer::OnPaint)
EVT_SIZE(ClusterImageViewer::OnSize)
END_EVENT_TABLE()
