#ifndef INDII_TINT_GUI_CLUSTERIMAGEVIEWER_HPP
#define INDII_TINT_GUI_CLUSTERIMAGEVIEWER_HPP

#include "wx/wx.h"

namespace indii {
  namespace tint {

    class ClusterImage;

    namespace gui {

      class Workspace;

/**
 * Viewer for clustered image.
 *
 * @author Lawrence Murray <lawrence@indii.org>
 * @version $Rev: 13 $
 * @date $Date: 2007-08-11 13:17:58 +0100 (Sat, 11 Aug 2007) $
 */
class ClusterImageViewer : public wxScrolledWindow {
public:
  /**
   * Constructor.
   *
   * @param parent Parent window.
   * @param image Image to display. Caller maintains ownership.
   */
  ClusterImageViewer(wxWindow* parent, ClusterImage* image);

  /**
   * Destructor.
   */
  virtual ~ClusterImageViewer();

  /**
   * Zoom in.
   */
  void ZoomIn();

  /**
   * Zoom out.
   */
  void ZoomOut();

  /**
   * Zoom to 1:1
   */
  void ZoomNormal();

  /**
   * Notify of change to display image. For example, when a cluster is
   * turned on/off.
   */
  void Notify();

  /**
   * Handle paint event.
   */
  void OnDraw(wxDC& dc);

  /**
   * Handle resize event.
   */
  void OnSize(wxSizeEvent& event);

private:
  void SetScrollbars();

  /**
   * Create scaled version of image after zoom.
   */
  void ScaleImage();

  /**
   * Cluster image.
   */
  ClusterImage* image;

  /**
   * Scaled image for display.
   */
  wxImage* scaledImage;

  /**
   * Zoom numerator.
   */
  int zoomNumerator;

  /**
   * Zoom denominator.
   */
  int zoomDenominator;

  DECLARE_EVENT_TABLE()

};

    }
  }
}

#endif
