#ifndef INDII_TINT_GUI_WORKSPACE_HPP
#define INDII_TINT_GUI_WORKSPACE_HPP

#include "wx/wx.h"
#include "wx/progdlg.h"
#include "wx/aui/aui.h"

namespace indii {
  namespace tint {

    class ClusterImage;

    namespace gui {

      class ClusterImageViewer;
      class ClusterImageEditor;

/**
 * Main work space.
 *
 * @author Lawrence Murray <lawrence@indii.org>
 * @version $Rev: 13 $
 * @date $Date: 2007-08-11 13:17:58 +0100 (Sat, 11 Aug 2007) $
 */
class Workspace : public wxFrame {
public:
  /**
   * Constructor.
   */
  Workspace(ClusterImage* image);

  /**
   * Destructor.
   */
  virtual ~Workspace();

  /**
   * Save the image.
   *
   * @param as True to force "Save As".
   *
   * @return True if the save was successful, false otherwise.
   */
  bool Save(bool as = false);

  /**
   * New menu item event.
   */
  void OnNew(wxCommandEvent& event);

  /**
   * Save menu item event.
   */
  void OnSave(wxCommandEvent& event);

  /**
   * Save as menu item event.
   */
  void OnSaveAs(wxCommandEvent& event);

  /**
   * Close menu item event.
   */
  void OnClose(wxCommandEvent& event);

  /**
   * Close event.
   */
  void OnSystemClose(wxCloseEvent& event);

  /**
   * Zoom in menu item event.
   */
  void OnZoomIn(wxCommandEvent& event);

  /**
   * Zoom out menu item event.
   */
  void OnZoomOut(wxCommandEvent& event);

  /**
   * Zoom normal menu item event.
   */
  void OnZoomNormal(wxCommandEvent& event);

  /**
   * About menu item event.
   */
  void OnAbout(wxCommandEvent& event);

private:
  /**
   * Clustered image.
   */
  ClusterImage* image;

  /**
   * Image viewer.
   */
  ClusterImageViewer* viewer;

  /**
   * Image editor.
   */
  ClusterImageEditor* editor;

  /**
   * File save as dialog.
   */
  wxFileDialog* dialogSaveAs;

  /**
   * File save error dialog.
   */
  wxMessageDialog* dialogSaveError;

  /**
   * File save prompt dialog.
   */
  wxMessageDialog* dialogSavePrompt;

  /**
   * AUI manager.
   */
  wxAuiManager* manager;

  /**
   * Events.
   */
  enum {
    ID_NEW = 1,
    ID_SAVE,
    ID_SAVEAS,
    ID_CLOSE,
    ID_ZOOMIN,
    ID_ZOOMOUT,
    ID_ZOOMNORMAL,
    ID_ABOUT
  };

  DECLARE_EVENT_TABLE()

};

    }
  }
}

#endif
